==> 4.0.2-DEV1.tar.gz: plan/Plan/src/main/java/com/djrapitops/plan/database/tables/Table.java <==
package main.java.com.djrapitops.plan.database.tables;

import com.djrapitops.plugin.utilities.Verify;
import com.google.common.base.Objects;
import main.java.com.djrapitops.plan.api.exceptions.DBCreateTableException;
import main.java.com.djrapitops.plan.database.databases.SQLDB;
import main.java.com.djrapitops.plan.database.processing.ExecStatement;
import main.java.com.djrapitops.plan.database.processing.QueryStatement;
import main.java.com.djrapitops.plan.utilities.MiscUtils;

import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;

/**
 * @author Rsl1122
 */
public abstract class Table {

    /**
     *
     */
    protected final String tableName;

    /**
     *
     */
    protected final SQLDB db;

    /**
     *
     */
    protected final boolean usingMySQL;

    /**
     * Constructor.
     *
     * @param name       Name of the table in the db.
     * @param db         Database to use.
     * @param usingMySQL Is the database using MySQL?
     */
    public Table(String name, SQLDB db, boolean usingMySQL) {
        this.tableName = name;
        this.db = db;
        this.usingMySQL = usingMySQL;
    }

    public abstract void createTable() throws DBCreateTableException;

    protected void createTable(String sql) throws DBCreateTableException {
        try {
            execute(sql);
        } catch (SQLException e) {
            throw new DBCreateTableException(tableName, "Failed to create table", e);
        }
    }

    /**
     * Used to get a new Connection to the Database.
     *
     * @return SQL Connection
     * @throws SQLException DB Error
     */
    protected Connection getConnection() throws SQLException {
        return db.getConnection();
    }

    /**
     * Get the Database Schema version from VersionTable.
     *
     * @return Database Schema version.
     * @throws SQLException DB Error
     */
    public int getVersion() throws SQLException {
        return db.getVersion();
    }

    /**
     * Executes an SQL Statement
     *
     * @param statementString Statement to setUp
     * @return What setUp returns.
     * @throws SQLException DB error
     */
    protected boolean execute(String statementString) throws SQLException {
        Statement statement = null;
        Connection connection = null;
        try {
            connection = getConnection();
            statement = connection.createStatement();
            boolean b = statement.execute(statementString);
            commit(connection);
            return b;
        } finally {
            close(statement);
            db.returnToPool(connection);
        }
    }

    /**
     * Used to setUp queries while possible SQLExceptions are suppressed.
     *
     * @param statements SQL statements to setUp
     */
    protected void executeUnsafe(String... statements) {
        Verify.nullCheck(statements);
        for (String statement : statements) {
            try {
                execute(statement);
            } catch (SQLException ignored) {
                /* Ignored */
            }
        }
    }

    /**
     * Closes DB elements.
     *
     * @param toClose All elements to close.
     */
    protected void close(AutoCloseable... toClose) {
        MiscUtils.close(toClose);
    }

    public String getTableName() {
        return tableName;
    }

    /**
     * Removes all data from the table.
     */
    public void removeAllData() throws SQLException {
        execute("DELETE FROM " + tableName);
    }

    protected void addColumns(String... columnInfo) {
        for (int i = 0; i < columnInfo.length; i++) {
            columnInfo[i] = "ALTER TABLE " + tableName + " ADD " + (usingMySQL ? "" : "COLUMN ") + columnInfo[i];
        }
        executeUnsafe(columnInfo);
    }

    protected void removeColumns(String... columnNames) {
        if (usingMySQL) {
            StringBuilder sqlBuild = new StringBuilder();
            sqlBuild.append("ALTER TABLE ").append(tableName);
            for (int i = 0; i < columnNames.length; i++) {
                sqlBuild.append(" DROP COLUMN ").append(columnNames[i]);
                if (i < columnNames.length - 1) {
                    sqlBuild.append(",");
                }
            }
            executeUnsafe(sqlBuild.toString());
        }
    }

    @Override
    public String toString() {
        return tableName;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Table table = (Table) o;
        return usingMySQL == table.usingMySQL &&
                Objects.equal(tableName, table.tableName) &&
                Objects.equal(db, table.db);
    }

    protected void commit(Connection connection) throws SQLException {
        db.commit(connection);
    }

    @Override
    public int hashCode() {
        return Objects.hashCode(tableName, db, usingMySQL);
    }

    public SQLDB getDb() {
        return db;
    }

    protected boolean execute(ExecStatement statement) throws SQLException {
        boolean updatedSomething = false;
        Connection connection = null;
        try {
            connection = getConnection();
            updatedSomething = statement.execute(connection.prepareStatement(statement.getSql()));
            commit(connection);
        } finally {
            db.returnToPool(connection);
        }
        return updatedSomething;
    }

    protected void executeBatch(ExecStatement statement) throws SQLException {
        Connection connection = null;
        try {
            connection = getConnection();
            statement.executeBatch(connection.prepareStatement(statement.getSql()));
            commit(connection);
        } finally {
            db.returnToPool(connection);
        }
    }

    protected <T> T query(QueryStatement<T> statement) throws SQLException {
        Connection connection = null;
        try {
            connection = getConnection();
            return statement.executeQuery(connection.prepareStatement(statement.getSql()));
        } finally {
            db.returnToPool(connection);
        }
    }
}

==> 4.0.6-DEV1.tar.gz: plan/Plan/src/main/java/com/djrapitops/plan/database/tables/Table.java <==
package main.java.com.djrapitops.plan.database.tables;

import com.djrapitops.plugin.utilities.Verify;
import com.google.common.base.Objects;
import main.java.com.djrapitops.plan.api.exceptions.DBCreateTableException;
import main.java.com.djrapitops.plan.database.databases.SQLDB;
import main.java.com.djrapitops.plan.database.processing.ExecStatement;
import main.java.com.djrapitops.plan.database.processing.QueryStatement;
import main.java.com.djrapitops.plan.utilities.MiscUtils;

import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;

/**
 * @author Rsl1122
 */
public abstract class Table {

    /**
     *
     */
    protected final String tableName;

    /**
     *
     */
    protected final SQLDB db;

    /**
     *
     */
    protected final boolean usingMySQL;

    /**
     * Constructor.
     *
     * @param name       Name of the table in the db.
     * @param db         Database to use.
     * @param usingMySQL Is the database using MySQL?
     */
    public Table(String name, SQLDB db, boolean usingMySQL) {
        this.tableName = name;
        this.db = db;
        this.usingMySQL = usingMySQL;
    }

    public abstract void createTable() throws DBCreateTableException;

    protected void createTable(String sql) throws DBCreateTableException {
        try {
            execute(sql);
        } catch (SQLException e) {
            throw new DBCreateTableException(tableName, "Failed to create table", e);
        }
    }

    /**
     * Used to get a new Connection to the Database.
     *
     * @return SQL Connection
     * @throws SQLException DB Error
     */
    protected Connection getConnection() throws SQLException {
        return db.getConnection();
    }

    /**
     * Get the Database Schema version from VersionTable.
     *
     * @return Database Schema version.
     * @throws SQLException DB Error
     */
    public int getVersion() throws SQLException {
        return db.getVersion();
    }

    /**
     * Executes an SQL Statement
     *
     * @param statementString Statement to setUp
     * @return What setUp returns.
     * @throws SQLException DB error
     */
    protected boolean execute(String statementString) throws SQLException {
        Statement statement = null;
        Connection connection = null;
        try {
            connection = getConnection();
            statement = connection.createStatement();
            boolean b = statement.execute(statementString);
//            Log.debug("Execute: " + statementString);
            commit(connection);
            return b;
        } finally {
            close(statement);
            db.returnToPool(connection);
        }
    }

    /**
     * Used to setUp queries while possible SQLExceptions are suppressed.
     *
     * @param statements SQL statements to setUp
     */
    protected void executeUnsafe(String... statements) {
        Verify.nullCheck(statements);
        for (String statement : statements) {
            try {
                execute(statement);
            } catch (SQLException ignored) {
                /* Ignored */
            }
        }
    }

    /**
     * Closes DB elements.
     *
     * @param toClose All elements to close.
     */
    protected void close(AutoCloseable... toClose) {
        MiscUtils.close(toClose);
    }

    public String getTableName() {
        return tableName;
    }

    /**
     * Removes all data from the table.
     */
    public void removeAllData() throws SQLException {
        execute("DELETE FROM " + tableName);
    }

    protected void addColumns(String... columnInfo) {
        for (int i = 0; i < columnInfo.length; i++) {
            columnInfo[i] = "ALTER TABLE " + tableName + " ADD " + (usingMySQL ? "" : "COLUMN ") + columnInfo[i];
        }
        executeUnsafe(columnInfo);
    }

    protected void removeColumns(String... columnNames) {
        if (usingMySQL) {
            StringBuilder sqlBuild = new StringBuilder();
            sqlBuild.append("ALTER TABLE ").append(tableName);
            for (int i = 0; i < columnNames.length; i++) {
                sqlBuild.append(" DROP COLUMN ").append(columnNames[i]);
                if (i < columnNames.length - 1) {
                    sqlBuild.append(",");
                }
            }
            executeUnsafe(sqlBuild.toString());
        }
    }

    @Override
    public String toString() {
        return tableName;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Table table = (Table) o;
        return usingMySQL == table.usingMySQL &&
                Objects.equal(tableName, table.tableName) &&
                Objects.equal(db, table.db);
    }

    protected void commit(Connection connection) throws SQLException {
        db.commit(connection);
    }

    @Override
    public int hashCode() {
        return Objects.hashCode(tableName, db, usingMySQL);
    }

    public SQLDB getDb() {
        return db;
    }

    protected boolean execute(ExecStatement statement) throws SQLException {
        boolean updatedSomething;
        Connection connection = null;
        try {
            connection = getConnection();
            updatedSomething = statement.execute(connection.prepareStatement(statement.getSql()));
            commit(connection);
        } finally {
            db.returnToPool(connection);
        }
        return updatedSomething;
    }

    protected void executeBatch(ExecStatement statement) throws SQLException {
        Connection connection = null;
        try {
            connection = getConnection();
            statement.executeBatch(connection.prepareStatement(statement.getSql()));
            commit(connection);
        } finally {
            db.returnToPool(connection);
        }
    }

    protected <T> T query(QueryStatement<T> statement) throws SQLException {
        Connection connection = null;
        try {
            connection = getConnection();
            return statement.executeQuery(connection.prepareStatement(statement.getSql()));
        } finally {
            db.returnToPool(connection);
        }
    }
}
